PRO alb_map_driver

;*************************************************************************
; Name: alb_map_driver
;
; Purpose:
;   This routine will create a pixel-level albedo map for a granule, as created 
;   when running the MOD06OD code.  This map is generated by reading in the 
;   geolocation arrays from the MOD03 HDF file, and for each geolocated point,
;   finding the nearest neighbor from the ecosystem ancillary file.  Ecosystems
;   are turned into albedos, depending on seasonality, and the albedo maps
;   are outputted into a new HDF file, along with the geolocation arrays.  The 
;   output hdf file is used as input to plot the albedos.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:	Date of the granule being plotted.
;   Output_Path:  	Directory to store the image produced.
;   temp_HDF_Path:  	Directory where the albedo map stored.
;   Input_Path:		Directory where the MOD03 file is stored.
;   IGBP_map_Path:	Directory where the Ecosystem map is stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  read_product_sds.pro
;  createecomap.pro
;  createalbedo.pro
;  outputalbedomap.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************

;*************************************************************************
;Define the year, julian date, and time for this run:
;*************************************************************************
;Read in the environmental variables for year, day, and time:
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')
jday = fix(day)


;************************************************************************
;Find the Geolocation file for the specified year, day, and time
;************************************************************************
;Specify the path where the MOD03, geolocation file resides:
;  Note:  Specify the full path:
fullpath = GETENV('Input_Path')

;Define the file name to look for and find the file:
file_spec = fullpath+'MOD03*'+year+day+'.'+time+'*.hdf'
result = FINDFILE(file_spec)
GeoFileName = strcompress(result(0))


;*************************************************************************
;Define the ancillary ecosystem map file, including full path:
;*************************************************************************
;Read in the location from perl script:
Eco_path = GETENV('IGBP_map_path')
OrigEcoMapFile = Eco_path + 'IGBP_map.v3.hdf'



;*************************************************************************
;Read in the Lat/Lon Arrays:
;*************************************************************************
GeoFileID = HDF_SD_START(GeoFileName,/READ)
Read_product_sds, LatArray, range, fillvalue, GeofileID, 'Latitude', $
 	          fail, /scaleNo, /offsetNo, /validrangeNo, /fillNo
Read_product_sds, LonArray, range, fillvalue, GeofileID, 'Longitude',$
                  fail, /scaleNo, /offsetNo, /validrangeNo, /fillNo
HDF_SD_END, GeoFileID


;*************************************************************************
;Create the Ecosystem map from nearest neighbor point:
;*************************************************************************
EcosystemMap = createecomap(LatArray,LonArray,OrigEcoMapFile)


;*************************************************************************
;Create the Ecosystem map from nearest neighbor point:
;*************************************************************************
AlbedoMap = createalbedo(jday,LatArray,EcosystemMap)


;*************************************************************************
;Output the ecosystem map to the HDF file:
;*************************************************************************
; Read in the temp HDF path from environmental variables:
temp_HDF_path = GETENV('temp_HDF_path')
AlbHDFFileName = temp_HDF_path + 'GranAlbMap.'+year+'.'+day+'.'+time+'.hdf'
dimSizes = size(LatArraY)
NGridX = dimSizes(1)
NGridY = dimSizes(2)
outputalbedomap, LatArray, LonArray, AlbedoMap, AlbHDFFileName, NGridX, NGridY


END
