pro plot_anci,filename,sds_name,outputname,sds_limits,Num_CB_Annotes,  $
              titlestring,multidim_choice

;*************************************************************************
; Name: plot_anci
;
; Purpose:
;   This routine is the main code for reading/altering data and creating
;     the image to be generated, as per input specifications.
;
; Inputs:
;  Environmental:
;   None.
;
;  Passed:
;   filename:           Path and HDF file name which contains the data set to plot.
;   sds_name:           Name of the data set to be plotted, as given in the HDF file.
;   outputname:         Path and file name of the image to be generated.
;   sds_limits:         Upper and lower data limits, used for applying color schemes.
;   Num_CB_Annotes:     The number of text annotations to be used on the colorbar.
;   titlesting:         String containing the title to be added to the top of the plot.
;   multidim_choice:    If the array is mulit-banded, this variable specifies which band is used.
;
; Outputs:
;  None. 
;
; Required Programs:
;  colorscale.pro
;  Read_Product_sds.pro
;  colorbar.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;Call to set up the color scale:
colorscale,r,g,b


;Read in the image data:
fileId = HDF_SD_START(filename, /READ)
  Read_product_sds,data,range,fillvalue,fileId,sds_name,fail,/scaleno,/validrangeno,/offsetno
HDF_SD_END, fileId

;get dimensions of sds data.  If there is more than one then use
;the multi-dimensional_choice argument to extract it.
temp_sizeinfo=size(data)
if (temp_sizeinfo(0) eq 3) then begin
  if temp_sizeinfo(3) gt temp_sizeinfo(1) then begin
    newdata=fltarr(temp_sizeinfo(2),temp_sizeinfo(3))
    newdata(*,*)=data(multidim_choice,*,*)
    data=newdata
    newdata = 0
  endif
  if temp_sizeinfo(1) gt temp_sizeinfo(3) then begin
    newdata=fltarr(temp_sizeinfo[1],temp_sizeinfo[2])
    newdata[*,*]=data[*,*,multidim_choice]
    data=newdata
    newdata = 0
  endif
endif

fillvalue = float(fillvalue)
data = float(data)

;Byte scale the data for output:
sds_image = bytscl( data,                      $
                    min = sds_limits(0),       $
                    max = sds_limits(1),       $
                    top = !d.table_size - 3  ) 


;Set the fill values to 255, or black:
fill_pixels = where((data eq fillvalue),fillcnt)
if fillcnt gt 0 then sds_image(fill_pixels) = 255B

;Set data array to 0:
data = 0




;Define various sizes used for createing the image.
;Obtain the size of the arrays:
dimsizes = size(sds_image)
data_xsize = dimsizes(1)
data_ysize = dimsizes(2)

;Define the extra space for the colorbar and margins:
xsize_factor  = 0.25
cb_xsize      = fix(xsize_factor * data_xsize)
ysize_factor  = 0.5
cb_ysize      = fix(ysize_factor * data_ysize)
margins       = 10
gap_cb_xsize  = 15
title_ysize   = 100

;Redefine the x and y sizes, to include margin and room for the colorbar:
xsize = data_xsize  + gap_cb_xsize + cb_xsize + margins * 2
ysize = data_ysize + margins * 2 + title_ysize




;Create the z buffer:
Set_plot, 'z',/COPY
Device, Set_Resolution=[xsize,ysize]
!p.font=3
Device,set_character_size=[24,24];,set_font='Helvetica',/tt_font


;"paint" the z buffer white:
temp_arr = bytarr(xsize,ysize)
temp_arr(*,*) = 254
tv, temp_arr


;Plot the colorbar to the z buffer:

;Define the position (in relative terms) of the colorbar:
;The colorbar begins to the right of the data, with a gap:
xbeg    = float(data_xsize + gap_cb_xsize + margins) / float(xsize)
;xend    = xbeg + float(cb_xsize) / float(xsize)
xend    = xbeg + 0.04
;The colorbar is to be centered on the y axis, define start/stop points:
ybeg    = float(ysize/2 - title_ysize - cb_ysize/2) / float(ysize)
yend    = ybeg + float(cb_ysize) / float(ysize)


;Call to plot the colorbar:
colorbar, /vertical, /right, position=[xbeg, ybeg, xend, yend],     $
          divisions=Num_CB_Annotes, range=sds_limits, font=1, format = '(F6.1)', $
          NCOLORS=254

;Center the title string at the top of the page:
xyouts, (float(data_xsize)/2.0+float(margins))/float(xsize), $
        float(ysize-margins-title_ysize/2)/float(ysize),     $
        titlestring, /NORMAL, alignment = 0.5,               $
        charsize = 0.7, charthick = 4

;Read the z buffer into image array:
image = tvrd()

;Close the z buffer:
device, /close

;Reverse the colorbar image for proper storage:
image = reverse(image,2)



;Store the data in the output array
for icnt = 0, data_xsize - 1 do begin
    for jcnt = 0, data_ysize -1 do begin
        image(icnt+margins,jcnt+margins+title_ysize) = sds_image(icnt,jcnt)
    endfor
endfor




;Write to the tiff file:
write_tiff,outputname,image,1,red=r,green=g,blue=b





end
