PRO eco

;*************************************************************************
; Name: eco
;
; Purpose:
;   This rountine is the main driver to plot a granule level IGBP ecosystem map.
;    Plotting variables are defined here and passed along to the plotting
;    routines.
;   Overall, this code reads in the granule's ecosystem map, generated in
;    the ecosystem mapping routine, and produces the ecosystem image.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   temp_HDF_Path  :  Directory where the ecosystem hdf map is stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_eco.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;*************************************************************************
; Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names. 
;*************************************************************************
;Define the text strings to use:
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')

;*************************************************************************
; Define the output directory:
;*************************************************************************
output_dir = GETENV('Output_Path')

;*************************************************************************
; Define the file that contains the ecomap.
;*************************************************************************
;Read in the location of the temp HDF file from memory:
temp_HDF_path = GETENV('temp_HDF_path')
filename = temp_HDF_path + 'Ecosystem.' + Year + '.' + Day + '.' + Time + '.hdf'

;*************************************************************************
; Define the text string that will appear after the sds name.
;*************************************************************************
EcoOutFileName = output_dir+'EcoMap.'+Year+'.'+Day+'.'+Time+'.tiff'


;*************************************************************************
; Define the text string that will appear in the plot title, after the sds name.
;*************************************************************************
titlestring = 'Ecosystem Map, Day '+Day+', '+Year+' '+Time + ' UTC.'


;*************************************************************************
;If you would like to specify the lat/lons to plot, please specify them
;   here.  This option is to be used if you want to specify a lat/lon box
;   of the granule(s) to plot.  The format is as follows:
;   	limits=[NorthBound,WestBound,SouthBound,EastBound]
;If you want the program to compute the bounds, please set limits = 0.
;*************************************************************************
limits=0.


;*************************************************************************
;Define the red, green, blue colors to use for the color bar.
;  Ex.  If the parameter is a yes, no, define the yes as green and 
;       the no as red, as follows:
;       values -> 0 = no, 1 = yes
;       rplot = [255,  0]
;       gplot = [  0,255]
;       bplot = [  0,  0] 
;*************************************************************************
;Define the Ecosystem color scheme:
rplot_arr =[255, 33,  0,  0,255,  0,255,  0,  0,255,255,179,255, 77,255,239, 71,255,230,200] 
gplot_arr =[ 50,255,239,  0, 15,138,204,  0,255,  0,255,255,  0,255,255,251,158,126, 53,200]
bplot_arr =[  0,  0,251,153,255,255,  0,255,  0,  0,  0,  0,  0,  0,255,  0,255,  0, 58,200] 


;*************************************************************************
; Define the annotations:
;*************************************************************************
allAnnote = ['Evrg. Needle Fr.','Evrg. Broad Fr.','Decd. Needle Fr.',$
             'Decd. Broad Fr.','Mixed Forest','Closed Shrubs',       $
             'Open/Shrubs','Woody Savanna','Savanna','Grassland',    $
             'Wetland','Cropland','Urban','Crop Mosaic',             $
             'Snow','Barren/Desert','Ocean Water',                   $
             'Tundra','Fresh Snow','Sea Ice'                         ]




;*************************************************************************
; End of definition section, make changes to the rest of the code at
; your own discretion.  If you wish to define a lat/lon box to plot,
; define it in the section below and choose the program call which
; includes the limits in the call.
;*************************************************************************




;*************************************************************************
;Define the sds_name to be plotted.
;*************************************************************************
sds_name = 'Ecosystem_Map'


;*************************************************************************
;Call the program:
;*************************************************************************
plot_eco, filename, sds_name, EcoOutFileName, titlestring, $
          allAnnote,rplot_arr,gplot_arr,bplot_arr


;*************************************************************************
;End the script:
;*************************************************************************

END
