pro plot_eco, filenames, sds_name, outputname, titlestring, $
              allAnnote, rplot, gplot, bplot

;*************************************************************************
; Name: plot_eco
;
; Purpose:
;   This routine is the main code for reading/altering data and creating
;     the image to be generated, as per input specifications.
;
; Inputs:
;  Environmental:
;   None.
;
;  Passed:
;   filename:           Path and HDF file name which contains the data set to plot.
;   sds_name:           Name of the data set to be plotted, as given in the HDF file.
;   outputname:         Path and file name of the image to be generated.
;   titlesting:         String containing the title to be added to the top of the plot.
;   allAnnote:		Array of strings which defines all of the ecosystem annotations.
;   rplot, 
;    gplot,
;    bplot   :          Arrays that store the RGB color assignments.
;
; Outputs:
;  None. 
;
; Required Programs:
;  Read_Product_sds.pro
;  make_key.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************



; Initialize the new color scheme for the bit field:
r = intarr(256)
g = intarr(256)
b = intarr(256)

;Set the user defined color scheme into r,g,b:
numcolors = size(rplot)
for icnt = 1, numcolors[1] do begin
    r[icnt] = rplot[icnt-1]
    g[icnt] = gplot[icnt-1]
    b[icnt] = bplot[icnt-1]
endfor

;Set the 254th spot to white:
r[254] = 255
g[254] = 255
b[254] = 255

;Set the 255th spot to black:
r[255] = 0
g[255] = 0
b[255] = 0

;Load in the color bar.
tvlct, r, g, b



;Read the image data:
fileId = HDF_SD_START(filenames[0],/READ)
read_product_sds, data, range, fillvalue, fileID, sds_name, fail, /offsetno, /scaleno
HDF_SD_END,fileId

;Set all fill values to black (255).
fill_pixels = where((data eq fillvalue),fillcnt)
if fillcnt gt 0 then data(fill_pixels) = 255

;Determine which ecosystems appear in the data:
colortmp = intarr(numcolors[1])
annottmp = strarr(numcolors[1])
numcolors = 0
for icnt = 1, 20 do begin
   dummyret = where(fix(data) eq fix(icnt), count)
   if ( count gt 0 ) then begin
       colortmp[numcolors] = icnt
       annottmp[numcolors] = allAnnote[icnt-1]
       numcolors = numcolors + 1
   endif
endfor

;Set up the final colors and labels arrays:
colors = intarr(numcolors)
annote = strarr(numcolors)
for jcnt = 0, numcolors-1 do begin
    colors[jcnt] = colortmp[jcnt]
    annote[jcnt] = annottmp[jcnt]
endfor





;Define various sizes used for creating the image.
;Obtain the size of the arrays:
dimsizes = size(data)
data_xsize = dimsizes(1)
data_ysize = dimsizes(2)

;Define the extra space for the colorbar and margins:
xsize_factor  = 0.25
cb_xsize      = fix(xsize_factor * data_xsize)
ysize_factor  = 0.5
cb_ysize      = fix(ysize_factor * data_ysize)
margins       = 10
gap_cb_xsize  = 15
title_ysize   = 100

;Redefine the x and y sizes, to include margin and room for the colorbar:
xsize = data_xsize  + gap_cb_xsize + cb_xsize + margins * 2
ysize = data_ysize + margins * 2 + title_ysize




;Create the z buffer:
Set_plot, 'z',/COPY
Device, Set_Resolution=[xsize,ysize]
!p.font=3
Device,set_character_size=[24,24];,set_font='Helvetica',/tt_font

;"paint" the z buffer white:
temp_arr = bytarr(xsize,ysize)
temp_arr(*,*) = 254
tv, temp_arr

;Plot the colorbar to the z buffer:

;Define the position (in relative terms) of the colorbar:
;The colorbar begins to the right of the data, with a gap:
xbeg    = float(data_xsize + gap_cb_xsize + margins) / xsize
;The colorbar is to be centered on the y axis, define start/stop points:
ybeg    = float(ysize/2 - title_ysize - cb_ysize/2)/ysize


;plot color bar, including all of the valid categories.
;want a tad off the colorbar, so mult by 0.30:
xoffset = xsize_factor * 0.18
;want in middle, so * by 0.5
yoffset = ysize_factor * 0.5 / numcolors
make_key, xbeg, ybeg,                             $
          0.15*xsize_factor, ysize_factor,        $
          xoffset, yoffset,                       $
          colors=colors, labels=annote,           $
          /normal, orientation = 1,               $
          Charsize = 0.7, charthick = 4


;Center the title string at the top of the page:
xyouts, (float(data_xsize)/2.0+float(margins))/float(xsize), $
        float(ysize-margins-title_ysize/2)/float(ysize),     $
        titlestring, /NORMAL, alignment = 0.5,               $
        charsize = 0.7, charthick = 4

;Read the z buffer into image array:
image = tvrd()

;Close the z buffer:
device, /close

;Reverse the colorbar image for proper storage:
image = reverse(image,2)



;Store the data in the output array
for icnt = 0, data_xsize - 1 do begin
    for jcnt = 0, data_ysize -1 do begin
        image(icnt+margins,jcnt+margins+title_ysize) = data(icnt,jcnt)
    endfor
endfor




;Write to the tiff file:
write_tiff,outputname,image,1,red=r,green=g,blue=b




end

