PRO cloudplot

;*************************************************************************
; Name: cloudplot
;
; Purpose:
;   This rountine is the main driver to plot granule level Cloud Mask fields.
;    Plotting variables are defined here and passed along to the plotting
;    routines.
;   Overall, this code reads in the granule's bit fields, generated in
;    the bit extraction routine, and produces the bit filed images.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   temp_HDF_Path  :  Directory where the albedo map stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_bit_fields.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;*************************************************************************
; Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names.
;*************************************************************************
;Define the text strings to use:
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')

;*************************************************************************
; Define the output directory:
;*************************************************************************
output_dir = GETENV('Output_Path')

;*************************************************************************
; Define the file that contains the bit fields.
;*************************************************************************
;Read in the location of the temp HDF file from memory:
temp_HDF_path = GETENV('temp_HDF_path')
filenames   = StrArr(1)
filenames[0] = temp_HDF_path + 'CloudMaskTests.'+Year+'.'+Day+'.'+Time+'.hdf'


;*************************************************************************
; Define the text string that will appear after the sds name.
;  Ex. The products will be named sdsname.textstring.tiff
;      So one use would be to have the year.day.hourminute
;      outtextstring = '2000.110.0855'
;*************************************************************************
outtextstring = '.'+Year+'.'+Day+'.'+Time


;*************************************************************************
; Define the text string that will appear in the plot title, after the sds name.
;*************************************************************************
plottextstring = ', Day '+Day+', '+Year+' '+Time + ' UTC.'


;*************************************************************************
;If you would like to specify the lat/lons to plot, please specify them
;   here.  This option is to be used if you want to specify a lat/lon box
;   of the granule(s) to plot.  The format is as follows:
;   	limits=[NorthBound,WestBound,SouthBound,EastBound]
;If you want the program to compute the bounds, please set limits = 0.
;*************************************************************************
limits=0.

;*************************************************************************
; Define which SDS you would like to produce a plot of. 
; 1 means yes, 0 means no.
;*************************************************************************
;Define the number of SDSs:
numSDS = 10
plot_sds    = intarr(numSDS)
plot_sds[0] = 1  ; Determined_Flag
plot_sds[1] = 1  ; Percent_Cloudy
plot_sds[2] = 1  ; Day_Night_Flag
plot_sds[3] = 1  ; Sun_Glint_Flag
plot_sds[4] = 1  ; Snow_Ice_Flag
plot_sds[5] = 1  ; Surface_Type
plot_sds[6] = 1  ; Heavy_Aerosol
plot_sds[7] = 1  ; Thin_Cirrus_Detect_Vis
plot_sds[8] = 1  ; Shadow_Found
plot_sds[9] = 1  ; Elevated Aerosol




;*************************************************************************
;*************************************************************************
; End of Definition section, Edit the lines below at your own risk.
;*************************************************************************
;*************************************************************************




;*************************************************************************
;Define the sds_name to be plotted.
;  For the cloud mask, the options are:
;	Determined_Flag, Percent_Cloudy, Day_Night_Flag, 
;	Sun_Glint_Flag, Snow_Ice_Flag, Surface_Type
;  For the L2 QA, the options are:
;*************************************************************************
sds_name_arr = strarr(numSDS)
sds_name_arr[0] = 'Determined_Flag'
sds_name_arr[1] = 'Percent_Cloudy'
sds_name_arr[2] = 'Day_Night_Flag'
sds_name_arr[3] = 'Sun_Glint_Flag'
sds_name_arr[4] = 'Snow_Ice_Flag'
sds_name_arr[5] = 'Surface_Type'
sds_name_arr[6] = 'Heavy_Aerosol'
sds_name_arr[7] = 'Thin_Cirrus_Detect_Vis'
sds_name_arr[8] = 'Shadow_Found'
sds_name_arr[9] = 'Elevated_Aerosol'


;*************************************************************************
;Define the sds_name to be outputted.
;*************************************************************************
sds_out_name_arr = strarr(numSDS)
sds_out_name_arr[0] = 'Determ_Flg'
sds_out_name_arr[1] = 'Perc_Cldy'
sds_out_name_arr[2] = 'Day_Ngt_Flg'
sds_out_name_arr[3] = 'Sun_Glt_Flg'
sds_out_name_arr[4] = 'Snw_Ice_Flg'
sds_out_name_arr[5] = 'Surf_Type'
sds_out_name_arr[6] = 'Hvy_Aerosl'
sds_out_name_arr[7] = 'Thn_Cir_Vis'
sds_out_name_arr[8] = 'Shdw_Fnd'
sds_out_name_arr[9] = 'Elev_Aerosl'


;*************************************************************************
;Define the red, green, blue colors to use for the color bar.
;  Ex.  If the parameter is a yes, no, define the yes as green and 
;       the no as red, as follows:
;       values -> 0 = no, 1 = yes
;       rplot = [255,  0]
;       gplot = [  0,255]
;       bplot = [  0,  0] 
;*************************************************************************
;Initialize the arrays:
rplot_arr = intarr(4,numSDS)
gplot_arr = intarr(4,numSDS)
bplot_arr = intarr(4,numSDS)
;Define the colors for Determined Flag:
; 0 = Undetermined (Red), 1 = Determined (Green)
rplot_arr[*,0] = [255,  0,  0,  0]
gplot_arr[*,0] = [  0,255,  0,  0]
bplot_arr[*,0] = [  0,  0,  0,  0]
;Define the colors for Percent Cloudy:
; 0 = Cloudy (White), 1 = Pr Cloudy (Green), 2 = Pr Clear (Blue), 3 = Conf. Clear (Grey) 
rplot_arr[*,1] = [255,  0,  0, 50]
gplot_arr[*,1] = [255,255,  0, 50]
bplot_arr[*,1] = [255,  0,255, 50]
;Define the colors for Day/Night Flag:
; 0 = Night (Dark Blue), 1 = Day (Yellow)
rplot_arr[*,2] = [100,239,  0,  0]
gplot_arr[*,2] = [100,251,  0,  0]
bplot_arr[*,2] = [255,  0,  0,  0]
;Define the colors for SunGlint Flag:
; 0 = Yes (White), 1 = No (Grey)
rplot_arr[*,3] = [235,150,  0,  0]
gplot_arr[*,3] = [235,150,  0,  0]
bplot_arr[*,3] = [235,150,  0,  0]
;Define the colors for Snow/Ice Flag:
; 0 = Yes (White), 1 = No (blue)
rplot_arr[*,4] = [245, 50,  0,  0]
gplot_arr[*,4] = [245, 50,  0,  0]
bplot_arr[*,4] = [245,255,  0,  0]
;Define the colors for the Land/Water Flag:
; 0 = Water (blue), 1 = Costal (red), 2 = Desert (Yellow), 3 = Land (Green)
rplot_arr[*,5] = [ 71,255,239,  0]
gplot_arr[*,5] = [158,  0,251,255]
bplot_arr[*,5] = [255,  0,  0,  0]
;Define the colors for Heavy Aerosol:
; 0 = Yes (White), 1 = No (Grey)
rplot_arr[*,6] = [255,100,  0,  0]
gplot_arr[*,6] = [255,100,  0,  0]
bplot_arr[*,6] = [255,100,  0,  0]
;Define the colors for Thin Cirrus Detected, visable:
; 0 = Yes (White), 1 = No (Grey)
rplot_arr[*,7] = [255,100,  0,  0]
gplot_arr[*,7] = [255,100,  0,  0]
bplot_arr[*,7] = [255,100,  0,  0]
;Define the colors for Shadow Found:
; 0 = Yes (White), 1 = No (Grey)
rplot_arr[*,8] = [255,100,  0,  0]
gplot_arr[*,8] = [255,100,  0,  0]
bplot_arr[*,8] = [255,100,  0,  0]
;Define the colors for Shadow Found:
; 0 = Yes (White), 1 = No (Grey)
rplot_arr[*,9] = [255,100,  0,  0]
gplot_arr[*,9] = [255,100,  0,  0]
bplot_arr[*,9] = [255,100,  0,  0]



;*************************************************************************
; Loop over all the sds and plot if sds_plot = 1:
;*************************************************************************
FOR icnt = 0, numSDS-1 DO BEGIN


   ;*************************************************************************
   ;Load the appropriate sds_name and color scheme:
   ;*************************************************************************
   sds_name = sds_name_arr[icnt]
   sds_out_name = sds_out_name_arr[icnt]
   rplot    = rplot_arr [*,icnt]
   gplot    = gplot_arr [*,icnt]
   bplot    = bplot_arr [*,icnt]


   ;*************************************************************************
   ; Provide the name and path of the output image file, for example:
   ;	OutFileName = 'GlobalEcosystemMap.3600X1800.tiff'
   ;*************************************************************************
   OutFileName = output_dir+sds_out_name+outtextstring+'.tiff'

   ;*************************************************************************
   ;Add a title to the plot if desired. Ex. titlestring ='Title'
   ;*************************************************************************
   titlestring = sds_name+plottextstring

   ;*************************************************************************
   ;Call the program:
   ;*************************************************************************
   ;Test to see if this SDS should be plotted:
   IF (plot_sds[icnt] eq 1) THEN BEGIN
      print, 'Plotting ',sds_name
      plot_bit_fields, filenames, sds_name, OutFileName, $
                       rplot, gplot, bplot, titlestring
   ENDIF ELSE BEGIN
      print, 'Skipping ',sds_name
   ENDELSE

;*************************************************************************
;End the looping:
;*************************************************************************
ENDFOR

;*************************************************************************
;End the script:
;*************************************************************************

END
