PRO l2qaplot

;*************************************************************************
; Name: l2qaplot
;
; Purpose:
;   This rountine is the main driver to plot granule level L2 QA fields.
;    Plotting variables are defined here and passed along to the plotting
;    routines.
;   Overall, this code reads in the granule's bit fields, generated in
;    the bit extraction routine, and produces the bit filed images.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   temp_HDF_Path  :  Directory where the albedo map stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_bit_fields.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
; it freely, subject to the following restrictions:
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;*************************************************************************
; Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names.
;*************************************************************************
;Define the text strings to use:
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')

;*************************************************************************
; Define the output directory:
;*************************************************************************
output_dir = GETENV('Output_Path')

;*************************************************************************
; Define the files that contain the bit fields.
;*************************************************************************
;Read in the location of the temp HDF file from memory:
temp_HDF_path = GETENV('temp_HDF_path')
filenames   = StrArr(1)
filenames[0] = temp_HDF_path + 'L2QAflags.'+Year+'.'+Day+'.'+Time+'.hdf'


;*************************************************************************
; Define the text string that will appear after the sds name.
;*************************************************************************
outtextstring = '.'+Year+'.'+Day+'.'+Time


;*************************************************************************
; Define the text string that will appear in the plot title, after the sds name.
;*************************************************************************
plottextstring = ', Day '+Day+', '+Year+' '+Time+'UTC.'


;*************************************************************************
;If you would like to specify the lat/lons to plot, please specify them
;   here.  This option is to be used if you want to specify a lat/lon box
;   of the granule(s) to plot.  The format is as follows:
;   	limits=[NorthBound,WestBound,SouthBound,EastBound]
;If you want the program to compute the bounds, please set limits = 0.
;*************************************************************************
limits=0.


;*************************************************************************
; Define which SDS you would like to produce a plot of. 
; 1 means yes, 0 means no.
;*************************************************************************
;Define the number of SDS:
numSDS = 20
plot_sds    = intarr(numSDS)
plot_sds[ 0] = 1  ; Opt_Thick_Gen_QA
plot_sds[ 1] = 1  ; Opt_Thick_Conf_QA
plot_sds[ 2] = 1  ; Opt_Thick_Out_of_Bounds
plot_sds[ 3] = 1  ; Eff_Rad_Gen_QA
plot_sds[ 4] = 1  ; Eff_Rad_Conf_QA
plot_sds[ 5] = 1  ; Liq_Wat_Path_Gen_QA
plot_sds[ 6] = 1  ; Liq_Wat_Path_Conf_QA
plot_sds[ 7] = 1  ; Cloud_Phase_Det_SWIR
plot_sds[ 8] = 1  ; Cloud_Phase_Retr_Proc_Path
plot_sds[ 9] = 1  ; Retrieval_Outcome
plot_sds[10] = 1  ; Rayleigh_Correction
plot_sds[11] = 1  ; Water_Vap_Corr
plot_sds[12] = 1  ; Band_Used_Opt_Thck_Retr
plot_sds[13] = 1  ; Total_Precip_Water
plot_sds[14] = 1  ; Cloud_Top_Height
plot_sds[15] = 1  ; Temp_Profile
plot_sds[16] = 1  ; Surf_Temp_Land
plot_sds[17] = 1  ; Surf_Temp_Ocean
plot_sds[18] = 1  ; BRDF_Albedo
plot_sds[19] = 1  ; Ozone_Prof



;*************************************************************************
;*************************************************************************
; End of Definition section, Edit the lines below at your own risk.
;*************************************************************************
;*************************************************************************



;*************************************************************************
;Define the sds_name to be plotted.
;*************************************************************************
sds_name_arr = strarr(numSDS)
sds_name_arr[ 0] = 'Opt_Thick_Gen_QA'
sds_name_arr[ 1] = 'Opt_Thick_Conf_QA'
sds_name_arr[ 2] = 'Opt_Thick_Out_of_Bounds'
sds_name_arr[ 3] = 'Eff_Rad_Gen_QA'
sds_name_arr[ 4] = 'Eff_Rad_Conf_QA'
sds_name_arr[ 5] = 'Liq_Wat_Path_Gen_QA'
sds_name_arr[ 6] = 'Liq_Wat_Path_Conf_QA'
sds_name_arr[ 7] = 'Cloud_Phase_Det_SWIR'
sds_name_arr[ 8] = 'Cloud_Phase_Retr_Proc_Path'
sds_name_arr[ 9] = 'Retrieval_Outcome'
sds_name_arr[10] = 'Rayleigh_Correction'
sds_name_arr[11] = 'Water_Vap_Corr'
sds_name_arr[12] = 'Band_Used_Opt_Thck_Retr'
sds_name_arr[13] = 'Ttl_Precip_Wtr_QA'
sds_name_arr[14] = 'Cld_Top_Hght_QA'
sds_name_arr[15] = 'Temp_Profile_QA'
sds_name_arr[16] = 'Surf_Temp_Land_QA'
sds_name_arr[17] = 'Surf_Temp_Ocn_QA'
sds_name_arr[18] = 'BRDF_Albedo'
sds_name_arr[19] = 'Ozone_Prof'


;*************************************************************************
;Define the sds_name to be plotted.
;*************************************************************************
sds_out_name_arr = strarr(numSDS)
sds_out_name_arr[ 0] = 'Opt_Thk_Gn_QA'
sds_out_name_arr[ 1] = 'Opt_Thk_Cf_QA'
sds_out_name_arr[ 2] = 'Opt_Thk_OOB'
sds_out_name_arr[ 3] = 'Eff_Rd_Gn_QA'
sds_out_name_arr[ 4] = 'Eff_Rd_Cnf_QA'
sds_out_name_arr[ 5] = 'Lq_Wt_Pth_Gn'
sds_out_name_arr[ 6] = 'Lq_Wt_Pth_Cnf'
sds_out_name_arr[ 7] = 'Cld_Phs_SWIR'
sds_out_name_arr[ 8] = 'Cld_Phs_RPP'
sds_out_name_arr[ 9] = 'Retr_Outcome'
sds_out_name_arr[10] = 'Ray_Correct'
sds_out_name_arr[11] = 'Wtr_Vap_Corr'
sds_out_name_arr[12] = 'Bnd_Usd_OT_Rt'
sds_out_name_arr[13] = 'Ttl_Prcp_Wtr'
sds_out_name_arr[14] = 'Cld_Top_Hght'
sds_out_name_arr[15] = 'Temp_Prof_QA'
sds_out_name_arr[16] = 'Srf_Tmp_Lnd'
sds_out_name_arr[17] = 'Srf_Tmp_Ocn'
sds_out_name_arr[18] = 'BRDF_Albedo'
sds_out_name_arr[19] = 'Ozone_Prof'



;*************************************************************************
;Define the red, green, blue colors to use for the color bar.
;  Ex.  If the parameter is a yes, no, define the yes as green and 
;       the no as red, as follows:
;       values -> 0 = no, 1 = yes
;       rplot = [255,  0]
;       gplot = [  0,255]
;       bplot = [  0,  0] 
;*************************************************************************
;Initialize the arrays:
rplot_arr = intarr(6,numSDS)
gplot_arr = intarr(6,numSDS)
bplot_arr = intarr(6,numSDS)
;Define the colors for Opt Thick Gen QA:
; 0 = Not Useful (Red), 1 = Useful (Green)
rplot_arr[*, 0] = [255,  0,  0,  0,  0,  0]
gplot_arr[*, 0] = [  0,255,  0,  0,  0,  0]
bplot_arr[*, 0] = [  0,  0,  0,  0,  0,  0]
;Define the colors for Opt Thick Conf QA:
; 0 = Bad (Red), 1 = Marginal (Yellow), 2 = Good (Blue), 3 = Very Good (Green) 
rplot_arr[*, 1] = [255,239,  0,  0,  0,  0]
gplot_arr[*, 1] = [  0,251,  0,255,  0,  0]
bplot_arr[*, 1] = [  0,  0,255,  0,  0,  0]
;Define the colors for Opt Thick out-of-bounds:
; 0=Within Bounds(Green), 1=100<OT<150(Blue),2=150<OT<200(Yellow),3=OT>200(Red)
rplot_arr[*, 2] = [  0,  0,239,255,  0,  0]
gplot_arr[*, 2] = [255,  0,251,  0,  0,  0]
bplot_arr[*, 2] = [  0,255,  0,  0,  0,  0]
;Define the colors for Eff Rad Gen QA
; 0 = not useful (Red), 1 = Useful (Green)
rplot_arr[*, 3] = [255,  0,  0,  0,  0,  0]
gplot_arr[*, 3] = [  0,255,  0,  0,  0,  0]
bplot_arr[*, 3] = [  0,  0,  0,  0,  0,  0]
;Define the colors for Eff Rad Conf QA:
; 0 = Bad (Red), 1 = Marginal (Yellow), 2 = Good (Blue), 3 = Very Good (Green) 
rplot_arr[*, 4] = [255,239,  0,  0,  0,  0]
gplot_arr[*, 4] = [  0,251,  0,255,  0,  0]
bplot_arr[*, 4] = [  0,  0,255,  0,  0,  0]
;Define the colors for Liq Water Path Gen QA:
; 0 = not useful (Red), 1 = Useful (Green)
rplot_arr[*, 5] = [255,  0,  0,  0,  0,  0]
gplot_arr[*, 5] = [  0,255,  0,  0,  0,  0]
bplot_arr[*, 5] = [  0,  0,  0,  0,  0,  0]
;Define the colors for Liq Water Path Conf QA:
; 0 = Bad (Red), 1 = Marginal (Yellow), 2 = Good (Blue), 3 = Very Good (Green) 
rplot_arr[*, 6] = [255,239,  0,  0,  0,  0]
gplot_arr[*, 6] = [  0,251,  0,255,  0,  0]
bplot_arr[*, 6] = [  0,  0,255,  0,  0,  0]
;Define the colors for Cloud Phase Det SWIR:
; 0 = Fill (Dark Grey), 1 = Clear (Grey), 2 = Cloud, Water (Blue), 
; 3 = Cloud, Ice (White), 4 = Cloud, Mixed/Undetermined (Green) 
rplot_arr[*, 7] = [ 75,150,  0,255,  0,  0]
gplot_arr[*, 7] = [ 75,150,  0,255,255,  0]
bplot_arr[*, 7] = [ 75,150,255,255,  0,  0]
;Define the colors for Cloud Phase Retr Proc Path:
; 0 = Cld Msk Undet (Dk Gry ),  1 = Dec Tree Stop(Grey ),
; 2 = Cloud, Water  (Blue ),    3 = Cloud, Ice   (White),
; 4 = Cloud, Undeter.  (Green), 5 = Cloud, Mixed (Red)
rplot_arr[*, 8] = [ 75,150,  0,255,  0,255]
gplot_arr[*, 8] = [ 75,150,  0,255,255,  0]
bplot_arr[*, 8] = [ 75,150,255,255,  0,  0]
;rplot_arr[*, 8] = [150,  0,255,  0,  0,  0]
;gplot_arr[*, 8] = [150,  0,255,255,  0,  0]
;bplot_arr[*, 8] = [150,255,255,  0,  0,  0]
;Define the colors for Retrieval Outcome:
; 0 = No Retrieval, unsuccessful(Red), 1 = Successful (Green)
rplot_arr[*, 9] = [255,  0,  0,  0,  0,  0]
gplot_arr[*, 9] = [  0,255,  0,  0,  0,  0]
bplot_arr[*, 9] = [  0,  0,  0,  0,  0,  0]
;Define the colors for Rayleigh Correction:
; 0 = No (Red), 1 = Yes (Green)
rplot_arr[*,10] = [255,  0,  0,  0,  0,  0]
gplot_arr[*,10] = [  0,255,  0,  0,  0,  0]
bplot_arr[*,10] = [  0,  0,  0,  0,  0,  0]
;Define the colors for Water Vapor Correction:
; 0 = No (Red), 1 = Yes (Green)
rplot_arr[*,11] = [255,  0,  0,  0,  0,  0]
gplot_arr[*,11] = [  0,255,  0,  0,  0,  0]
bplot_arr[*,11] = [  0,  0,  0,  0,  0,  0]
;Define the colors for Band Used for Optical Thickness Ret:
; 0 = Not Retrieved (Grey),    1 = 0.645 mm - land (Green), 
; 2 = 0.858 mm -water (Blue), 3 = 1.24  mm - snow/ice (White) 
rplot_arr[*,12] = [150,  0,  0,255,  0,  0]
gplot_arr[*,12] = [150,255,  0,255,  0,  0]
bplot_arr[*,12] = [150,  0,255,255,  0,  0]
;Define the colors for Total Precip Water:
; 0 = NCEP GDAS (Green),  1 = DAO (Blue), 
; 2 = MOD05-NIR (Yellow), 3 = MOD07-IR (Grey) 
rplot_arr[*,13] = [  0,  0,239,150,  0,  0]
gplot_arr[*,13] = [255,  0,251,150,  0,  0]
bplot_arr[*,13] = [  0,255,  0,150,  0,  0]
;Define the colors for Cloud Top Height:
; 0 = MOD06 (Green),  1 = DAO (Blue), 
; 2 = Other (Yellow), 3 = Not Used (Grey) 
rplot_arr[*,14] = [  0,  0,239,150,  0,  0]
gplot_arr[*,14] = [255,  0,251,150,  0,  0]
bplot_arr[*,14] = [  0,255,  0,150,  0,  0]
;Define the colors for Temp Profile:
; 0 = NCEP GDAS (Green),  1 = DAO (Blue), 
; 2 = MOD11    (Yellow),  3 = Other (Grey) 
rplot_arr[*,15] = [  0,  0,239,150,  0,  0]
gplot_arr[*,15] = [255,  0,251,150,  0,  0]
bplot_arr[*,15] = [  0,255,  0,150,  0,  0]
;Define the colors for Surf Temp Over Land:
; 0 = NCEP GDAS (Green),  1 = DAO (Blue), 
; 2 = MOD11     (Yellow), 3 = Not Used (Grey) 
rplot_arr[*,16] = [  0,  0,239,150,  0,  0]
gplot_arr[*,16] = [255,  0,251,150,  0,  0]
bplot_arr[*,16] = [  0,255,  0,150,  0,  0]
;Define the colors for Surf Temp Over Ocean:
; 0 = Reynolds Blended (Green),  1 = NCEP (Blue), 
; 2 = DAO             (Yellow),  3 = MOD28 (Grey) 
rplot_arr[*,17] = [  0,  0,239,150,  0,  0]
gplot_arr[*,17] = [255,  0,251,150,  0,  0]
bplot_arr[*,17] = [  0,255,  0,150,  0,  0]
;Define the colors for BRDF/Albedo:
; 0 = MOD43  (Green),  1 = DAO (Blue), 
; 2 = CERES (Yellow),  3 = Other (Grey) 
rplot_arr[*,18] = [  0,  0,239,150,  0,  0]
gplot_arr[*,18] = [255,  0,251,150,  0,  0]
bplot_arr[*,18] = [  0,255,  0,150,  0,  0]
;Define the colors for Ozone Profile:
; 0 = TOMS (Green),  1 = TOVS (Blue), 
; 2 = DAO (Yellow),  3 = Other (Grey) 
rplot_arr[*,19] = [  0,  0,239,150,  0,  0]
gplot_arr[*,19] = [255,  0,251,150,  0,  0]
bplot_arr[*,19] = [  0,255,  0,150,  0,  0]


;*************************************************************************
; Loop over all the sds and plot if sds_plot = 1:
;*************************************************************************
FOR icnt = 0, numSDS-1 DO BEGIN


   ;*************************************************************************
   ;Load the appropriate sds_name and color scheme:
   ;*************************************************************************
   sds_name     = sds_name_arr[icnt]
   sds_out_name = sds_out_name_arr[icnt] 
   rplot    = rplot_arr [*,icnt]
   gplot    = gplot_arr [*,icnt]
   bplot    = bplot_arr [*,icnt]


   ;*************************************************************************
   ; Provide the name and path of the output image file, for example:
   ;	OutFileName = 'GlobalEcosystemMap.3600X1800.ps'
   ;*************************************************************************
   OutFileName = output_dir+sds_out_name+outtextstring+'.tiff'


   ;*************************************************************************
   ;Add a title to the plot if desired. Ex. titlestring ='Title'
   ;*************************************************************************
   titlestring = sds_name+' '+plottextstring


   ;*************************************************************************
   ;Call the program:
   ;*************************************************************************
   ;Test to see if this SDS should be plotted:
   IF (plot_sds[icnt] eq 1) THEN BEGIN
      print, 'Plotting ',sds_name
      plot_bit_fields, filenames, sds_name, OutFileName, $
                       rplot, gplot, bplot, titlestring
   ENDIF ELSE BEGIN
      print, 'Skipping ',sds_name
   ENDELSE

;*************************************************************************
;End the looping:
;*************************************************************************
ENDFOR

;*************************************************************************
;End the script:
;*************************************************************************

END
