pro output_ir_flag, Lat, Lon, QAFlags, outHDFFileName, day, year, time


;*************************************************************************
; Name: output_ir_flag
;
; Purpose:
; outputIRbits.pro creates a new HDF file and outputs the lat/lon arrays,
;   as well as byte arrays containing the individual QA Flag results.
;   Local and global attributes are added as metadata.
;
;
; Input: 
;    Lat           	Float Array: Latitude array
;    Lon	   	Float Array: Longitude array
;    QAFlags	        Byte Array : L2 QA Flags
;    outHDFFileName	String     : Name of the output HDF file
;    day		String	   : Julian Day
;    year		String     : Year
;    time		String	   : Time as HHMM (H=hour, M=minute)
; 
; Output:
;    none
;
; Required Programs:
;    none
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;***********************************************************
;Create the hdf file:
;***********************************************************
outHDFFileID = HDF_SD_START(outHDFFileName,/CREATE)


;***********************************************************
;Write the global attributes:
;***********************************************************
title        = 'Level 2, MOD06, Quality Assurance Flags, 1KM'
creationDate = Systime()
createdBy    = 'Eric Moody (eric.moody@gsfc.nasa.gov)
scienceTeam  = 'NASA/GSFC Cloud Retrieval Group'
sensor       = 'Terra'
dataProduct  = 'MOD06OD'

HDF_SD_ATTRSET, outHDFFileID, 'Title', title, STRLEN(title)
HDF_SD_ATTRSET, outHDFFileID, 'JulianDay', day, STRLEN(day)
HDF_SD_ATTRSET, outHDFFileID, 'Year', year, STRLEN(year)
HDF_SD_ATTRSET, outHDFFileID, 'Time (HHMM)', time, STRLEN(time)
HDF_SD_ATTRSET, outHDFFileID, 'CreationDate', creationDate, STRLEN(creationDate)
HDF_SD_ATTRSET, outHDFFileID, 'CreatedBy', createdBy, STRLEN(createdBy)
HDF_SD_ATTRSET, outHDFFileID, 'ScienceTeam', scienceTeam, STRLEN(scienceTeam)
HDF_SD_ATTRSET, outHDFFileID, 'Platform', sensor, STRLEN(sensor)
HDF_SD_ATTRSET, outHDFFileID, 'AncillaryProductFor', dataProduct, STRLEN(dataProduct)


;***********************************************************
;Determine the 5km Xdimension and Ydimensions and name them:
;***********************************************************
dims = size(Lat,/dimensions)
xdim = dims(0)
ydim = dims(1)
xname = 'Cell_Along_Swath_5km'
yname = 'Cell_Across_Swath_5km'


;***********************************************************
;Create the Lat SDS:
;***********************************************************
;Create the Lat SDS, and rename the dimensions:
LatID = HDF_SD_CREATE(outHDFFileID, 'Latitude', [xdim,ydim], /FLOAT)
dimid = HDF_SD_DIMGETID(LatID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(LatID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the Lat local attributes:
Long_Name = 'Geodetic Latitude'
units = "degrees_north" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, LatID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, LatID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, LatID, '_FillValue', [-999.9], /FLOAT
HDF_SD_ATTRSET, LatID, 'valid_range', [-90.0, 90.0], /FLOAT
HDF_SD_ATTRSET, LatID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, LatID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, LatID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, LatID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the Lat SDS:
HDF_SD_ADDDATA, LatID, Lat

;End access to the Lat SDS:
HDF_SD_ENDACCESS, LatID


;***********************************************************
;Create the Lon SDS:
;***********************************************************
;Create the Lon SDS, and rename the dimensions:
LonID = HDF_SD_CREATE(outHDFFileID, 'Longitude', [xdim,ydim], /FLOAT)
dimid = HDF_SD_DIMGETID(LonID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(LonID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the Lon local attributes:
Long_Name = 'Geodetic Longitude'
units = "degrees_east" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, LonID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, LonID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, LonID, '_FillValue', [-999.9], /FLOAT
HDF_SD_ATTRSET, LonID, 'valid_range', [-180.0, 180.0], /FLOAT
HDF_SD_ATTRSET, LonID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, LonID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, LonID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, LonID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the Lon SDS:
HDF_SD_ADDDATA, LonID, Lon

;End access to the Lon SDS:
HDF_SD_ENDACCESS, LonID



;***********************************************************
;Determine the 1km Xdimension and Ydimensions and name them:
;***********************************************************
dims = size(QAFlags,/dimensions)
xdim = dims(0)
ydim = dims(1)
xname = 'Cell_Along_Swath_1km'
yname = 'Cell_Across_Swath_1km'


;***********************************************************
;Create the IR Phase:
;***********************************************************
;Create the SDS, and rename the dimensions:
SDSID = HDF_SD_CREATE(outHDFFileID, 'IR_Phase', [xdim,ydim], /BYTE)
dimid = HDF_SD_DIMGETID(SDSID,0)
  	HDF_SD_DIMSET, dimid, name=xname, /BW_INCOMP
dimid = HDF_SD_DIMGETID(SDSID,1)
  	HDF_SD_DIMSET, dimid, name=yname, /BW_INCOMP

;Add the L2QAFlag's local attributes:
Long_Name = 'Cloud Phase Infrared'
units = "none" ;
ParmType = "MODIS Input" ;
GeoPointer = "Internal geolocation arrays" 
HDF_SD_ATTRSET, SDSID, 'Long_Name', Long_Name, STRLEN(Long_Name)
HDF_SD_ATTRSET, SDSID, 'units', units, STRLEN(units)
HDF_SD_ATTRSET, SDSID, '_FillValue', [-9999], /INT
HDF_SD_ATTRSET, SDSID, 'valid_range', [0, 4], /INT
HDF_SD_ATTRSET, SDSID, 'scale_factor', [1.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'add_offset', [0.0], /FLOAT
HDF_SD_ATTRSET, SDSID, 'valid_values', [0,1,2,3,4], /INT
strvalue = 'Clear Sky'
HDF_SD_ATTRSET, SDSID, 'annot_value_0', strvalue, STRLEN(strvalue)
strvalue = 'Cloud, Water'
HDF_SD_ATTRSET, SDSID, 'annot_value_1', strvalue, STRLEN(strvalue)
strvalue = 'Cloud, Ice'
HDF_SD_ATTRSET, SDSID, 'annot_value_2', strvalue, STRLEN(strvalue)
strvalue = 'Cloud, Mixed'
HDF_SD_ATTRSET, SDSID, 'annot_value_3', strvalue, STRLEN(strvalue)
strvalue = 'Cld, Uncertain'
HDF_SD_ATTRSET, SDSID, 'annot_value_4', strvalue, STRLEN(strvalue)
HDF_SD_ATTRSET, SDSID, 'Parameter_Type', ParmType, STRLEN(ParmType)
HDF_SD_ATTRSET, SDSID, 'Geolocation_Pointer', GeoPointer, STRLEN(GeoPointer)

;Add data to the QAFlags array:
HDF_SD_ADDDATA, SDSID, QAFlags[*,*,0]

;End access to the QAFlags SDS:
HDF_SD_ENDACCESS, SDSID


;***********************************************************
;End access to the HDF file:
;***********************************************************
HDF_SD_END, outHDFFileID


end
