pro colorscale_phase, LUTR, LUTG, LUTB

;*************************************************************************
; Name: colorscale_phase
;
; Purpose:
;   This routine sets up the colorscale to be used for byte scaling the data
;    and defines the colors to be used for black (255) and white (254).  The
;    data will be scaled, in some form, between 0 and 253, based upon the
;    min and max specified.
;   This color scheme provides two distinct scales.
;
; Inputs:
;  Environmental:
;   None.
;
;  Passed:
;   None.
;
; Outputs:
;  LUTR, LUTG, LUTB:    These are the color assignments form Red, Green, and Blue.
;
; Required Programs:
;  None.
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody.
;  eric.moody@gsfc.nasa.gov
;  Code 913 NASA/GSFC
;  Greenbelt, MD 20771
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************



;We will use linear fits to scale the colors,
; so, the basic equation is y = A + Bx
; with boundary conditions as:
;  y1 = A + B x1
;  y2 = A + B x2
;where B = (y2-y1)/(x2-x1)
; and  A = y1 - x1 B


;Create the arrays for the color scale:
LUTR=BYTARR(256)
LUTG=BYTARR(256)
LUTB=BYTARR(256)


;;;;;;;;;;;;;;;;;;
; RED
;;;;;;;;;;;;;;;;;;


;Ice will range between 0 and 126, the 
; colors will range between purple,blue,green
;First start with a light purple and fade to a
; dark purple.  Red will go from 185 to 100
; over 42 levels.
y1 = 185.
x1 = 0.
y2 = 100.
x2 = 42.
B  = (y2-y1) / (x2-x1)
A  = y1 - x1 * B
FOR INDEX = fix(x1), fix(x2) do begin
  LUTR(INDEX) = A + B * float(INDEX)
end

;Next Fade the Red to zero, to create a deep blue,
;  and then go to pure blue (blue=255):
y1 = 100.
x1 = 42.
y2 = 0.
x2 = 84.
B  = (y2-y1) / (x2-x1)
A  = y1 - x1 * B
FOR INDEX = fix(x1), fix(x2) do begin
  LUTR(INDEX) = A + B * float(INDEX)
end

;The final part of the ice range is green, so
; red = 0
LUTR(85:126)=0


;The Water will go yellow to pink to red, by first
; having r&g=255 and b=0, then bring blue up to 180,
; then bring g down to 0, creating pink, then bring
; b down to 0 to create red, then bring r down to
; 130 to create a dark red.
;Red will be 255 until the last bit, where we bring
; it down to create a dark red.
LUTR(127:230) = 255

y1 = 255.
x1 = 231.
y2 = 130.
x2 = 253.
B  = (y2-y1) / (x2-x1)
A  = y1 - x1 * B
FOR INDEX = fix(x1), fix(x2) do begin
   LUTR(INDEX) = A + B * float(INDEX)
end


;;;;;;;;;;;;;;;;;;
; GREEN
;;;;;;;;;;;;;;;;;;
;For the ice scale, there isn't any green
; Until the last part, which goes from
;  a green of 150 to 255 over the last 3rd.
; The start of the color bar:
LUTG(0:84)=0

;Scale the green from 150 to 255:
y1 = 0.
x1 = 45.
y2 = 255.
x2 = 126.
B  = (y2-y1) / (x2-x1)
A  = y1 - x1 * B
FOR INDEX = fix(x1), fix(x2) do begin
  LUTG(INDEX) = A + B * float(INDEX)
end


;For the water scale, green will be 255, until
; we create the pink, in the second third:
LUTG(127:169)=255

;Now Bring G down to 230 over 6 spots, to create very
; light orange:
y1 = 255.
x1 = 170.
y2 = 230.
x2 = 175.
B  = (y2-y1) / (x2-x1)
A  = y1 - x1 * B
FOR INDEX = fix(x1), fix(x2) do begin
  LUTG(INDEX) = A + B * float(INDEX)
end

;Now bring G down to 133 over 176-211
y1 = 230.
x1 = 176.
y2 = 133.
x2 = 211.
B  = (y2-y1) / (x2-x1)
A  = y1 - x1 * B
FOR INDEX = fix(x1), fix(x2) do begin
  LUTG(INDEX) = A + B * float(INDEX)
end

;Lastly bring G down to 0 from 212-230:
y1 = 133.
x1 = 212.
y2 = 0.
x2 = 230.
B  = (y2-y1) / (x2-x1)
A  = y1 - x1 * B
FOR INDEX = fix(x1), fix(x2) do begin
  LUTG(INDEX) = A + B * float(INDEX)
end

;Green is 0 for the last stretch:
LUTG(231:253) = 0


;;;;;;;;;;;;;;;;;;
; BLUE
;;;;;;;;;;;;;;;;;;
;For the ice scale, the blue starts at 185 and drops
; to 145 over the first third, to create a deep purple,
; then moves up to 255 over the next third, and then
; fades to 0 for the last third to get green:
; Go from 185 to 145 for purple:
y1 = 185.
x1 = 0.
y2 = 145.
x2 = 42.
B  = (y2-y1) / (x2-x1)
A  = y1 - x1 * B
FOR INDEX = fix(x1), fix(x2) do begin
  LUTB(INDEX) = A + B * float(INDEX)
end

;Then go up to all blue:
y1 = 145.
x1 = 42.
y2 = 255.
x2 = 84.
B  = (y2-y1) / (x2-x1)
A  = y1 - x1 * B
FOR INDEX = fix(x1), fix(x2) do begin
  LUTB(INDEX) = A + B * float(INDEX)
end

;Then drop to zero:
y1 = 255.
x1 = 84.
y2 = 0.
x2 = 126.
B  = (y2-y1) / (x2-x1)
A  = y1 - x1 * B
FOR INDEX = fix(x1), fix(x2) do begin
  LUTB(INDEX) = A + B * float(INDEX)
end


;For water, bring blue up to 180 over the first
; third to create light yellows, then keep at 180 over the next 6, to
; create the light orange, then drop to 0 from 176-211 to create the
; oranges, then end at 0 for the rest of the scale.
;Create the light yellows:
y1 = 0.
x1 = 127.
y2 = 180.
x2 = 169.
;x2 = 155.
B  = (y2-y1) / (x2-x1)
A  = y1 - x1 * B
FOR INDEX = fix(x1), fix(x2) do begin
  LUTB(INDEX) = A + B * float(INDEX)
end

;Keep blue at 180 over the next 6:
LUTB(170:175) = 180

;Drop blue down to 0 over 176-211 to create oranges:
y1 = 180.
x1 = 176.
y2 = 0.
x2 = 211.
B  = (y2-y1) / (x2-x1)
A  = y1 - x1 * B
FOR INDEX = fix(x1), fix(x2) do begin
  LUTB(INDEX) = A + B * float(INDEX)
end

;Keep it at zero for the rest:
LUTB(211:253)=0


;;;;;;;;;;;;;;;;;;
; GREY-for greater than top limit.
;;;;;;;;;;;;;;;;;;
LUTR(253)=150
LUTG(253)=150
LUTB(253)=150

;;;;;;;;;;;;;;;;;;
; DARK GREY-for less than bottom limit.
;;;;;;;;;;;;;;;;;;
LUTR(0)=75
LUTG(0)=75
LUTB(0)=75

;;;;;;;;;;;;;;;;;;
; WHITE
;;;;;;;;;;;;;;;;;;
;reserve 254 (white) - background and coastlines
LUTR(254)  = 255
LUTG(254)  = 255
LUTB(254)  = 255


;;;;;;;;;;;;;;;;;;
; BLACK
;;;;;;;;;;;;;;;;;;
;reserve 255 (black) - text
LUTR(255)  =0
LUTG(255)  =0
LUTB(255)  =0








tvlct,LUTR,LUTG,LUTB


end
