PRO mod06

;*************************************************************************
; Name: mod06
;
; Purpose:
;   This rountine is the main driver to plot the mod06 variables.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   Input_Path     :  Directory where the L2 file is stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_l2.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;*************************************************************************
;  Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names.
;*************************************************************************
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')


;*************************************************************************
; Define the output directory:
;*************************************************************************
output_dir = GETENV('Output_Path')



;*************************************************************************
; Define the files that contain the L2 data, including path.  
;*************************************************************************
;Specify the path where the MOD06 file resides:
;  Note:  Specify the full path:
fullpath = GETENV('Input_Path')

;Define the file name to look for and find the file:
file_spec = fullpath+'MOD06_*'+year+day+'.'+time+'*.hdf'
result = FINDFILE(file_spec)
MOD06filename = strcompress(result(0))
print, MOD06filename


;*************************************************************************
; Define the SDSs to plot.  If the SDS is to be plotted, set 
; the value to 1, if not, set to 0.
;*************************************************************************
numSDS      = 9
PlotSDS    = IntArr(numSDS)
PlotSDS[0] = 1 ; Surface Temperature 
PlotSDS[1] = 1 ; Surface Pressure
PlotSDS[2] = 1 ; Cloud Top Pressure
PlotSDS[3] = 1 ; Cloud Top Temperature
PlotSDS[4] = 1 ; Effective Particle Radius
PlotSDS[5] = 1 ; Cloud Optical Thickness 
PlotSDS[6] = 0 ; Effective Particle Rad, 2.1-1.6
PlotSDS[7] = 0 ; Effective Particle Rad, 3.7-2.1
PlotSDS[8] = 1 ; Water Path

;*************************************************************************
; Definition of the names to use in the output file names for each SDS:
;*************************************************************************
OutName    = StrArr(numSDS)
OutName[0] = 'Surf_Temp'
OutName[1] = 'Surf_Pres'
OutName[2] = 'Cld_Top_Pres'
OutName[3] = 'Cld_Top_Temp'
OutName[4] = 'Eff_Part_Rad'
OutName[5] = 'Cld_Opt_Thck'
OutName[6] = 'EPRD_2.1-1.6'
OutName[7] = 'EPRD_3.7-2.1'
OutName[8] = 'Water_Path'


;*************************************************************************
; Definition of the names to use in the output file names for each SDS:
;*************************************************************************
TitleName    = StrArr(numSDS)
TitleName[0] = 'Surface Temperature'
TitleName[1] = 'Surface Pressure'
TitleName[2] = 'Cloud Top Pressure'
TitleName[3] = 'Cloud Top Temperature'
TitleName[4] = 'Effective Particle Radius'
TitleName[5] = 'Cloud Optical Thickness'
TitleName[6] = '2.1-1.6 Micron Effective Radius Difference'
TitleName[7] = '3.7-2.1 Micron Effective Radius Difference'
TitleName[8] = 'Water Path'


;*************************************************************************
; Define the SDS limits, as [min, max]:
;*************************************************************************
SDSLimits      = FltArr(numSDS,2)
SDSLimits[0,0] = 275.  ;150.  ;Surface Temperature, min
SDSLimits[0,1] = 310.  ;350.  ;Surface Temperature, max
SDSLimits[1,0] = 1000. ;800.  ;Surface Pressure, min
SDSLimits[1,1] = 1030. ;1100. ;Surface Pressure, max
SDSLimits[2,0] = 300.  ;Cld_Top_Pressure, min
SDSLimits[2,1] = 1000. ;Cld_Top_Pressure, max
SDSLimits[3,0] = 200.  ;Cld_Top_Temp, min
SDSLimits[3,1] = 300.  ;Cld_Top_Temp, max
SDSLimits[4,0] = 0.    ;Effective Particle Radius, min
SDSLimits[4,1] = 40.   ;Effective Particle Radius, max
SDSLimits[5,0] = 1.    ;Cloud Optical Thickness, min
SDSLimits[5,1] = 100.  ;Cloud Optical Thickness, max
SDSLimits[6,0] = -10.0 ;Re Diff 2.1-1.6, min
SDSLimits[6,1] =  10.0 ;Re Diff 2.1-1.6, max
SDSLimits[7,0] = -10.0 ;Re Diff 3.7-2.1, min
SDSLimits[7,1] =  10.0 ;Re Diff 3.7-2.1, max 
SDSLimits[8,0] = 0.    ;Water Path min
SDSLimits[8,1] = 400.  ;Water Path max


;*************************************************************************
; Choose the number of annotations to be included on the color bar:
;*************************************************************************
Num_CB_Annotes    = IntArr(numSDS)
Num_CB_Annotes[0] = 5 ;Surface Temperature
Num_CB_Annotes[1] = 6 ;Surface Pressure
Num_CB_Annotes[2] = 5 ;Cld_Top_Pressure
Num_CB_Annotes[3] = 5 ;Cld_Top_Temp
Num_CB_Annotes[4] = 5 ;Effective Particle Radius
Num_CB_Annotes[5] = 5 ;Cloud Optical Thickness
Num_CB_Annotes[6] = 5 ;Re Diff 1.6-2.1
Num_CB_Annotes[7] = 5 ;Re Diff 3.7-2.1
Num_CB_Annotes[8] = 5 ;Water Path


;*************************************************************************
; Define the SDS units:
;*************************************************************************
SDSunits      = StrArr(numSDS)
;MOD06 SDSs:
SDSunits[0]   = 'K'
SDSunits[1]   = 'hPa'
SDSunits[2]   = 'hPa'
SDSunits[3]   = 'K'
SDSunits[4]   = 'micron'
SDSunits[5]   = 'no units'
SDSunits[6]   = 'micron'
SDSunits[7]   = 'micron'
SDSunits[8]   = 'g/m^2'


;*************************************************************************
; Definition of the names of the SDS as defined in the HDF file.
;*************************************************************************
SDSName    = StrArr(numSDS)
;MOD06 SDSs:
SDSName[0] = 'Surface_Temperature'
SDSName[1] = 'Surface_Pressure'
SDSName[2] = 'Cloud_Top_Pressure'
SDSName[3] = 'Cloud_Top_Temperature'
SDSName[4] = 'Effective_Particle_Radius'
SDSName[5] = 'Cloud_Optical_Thickness'
SDSName[6] = 'Effective_Radius_Difference'
SDSName[7] = 'Effective_Radius_Difference'
SDSName[8] = 'Water_Path'



;*************************************************************************
;Multi dimension choice:
; Single banded have MDchoice = 0, Multi banded start with 0.
;*************************************************************************
MDchoice    = IntArr(numSDS)
;MOD06 SDSs:
MDchoice[0] = 0
MDchoice[1] = 0
MDchoice[2] = 0
MDchoice[3] = 0
MDchoice[4] = 0 
MDchoice[5] = 0
MDchoice[6] = 0
MDchoice[7] = 1
MDchoice[8] = 0

;*************************************************************************
; Plot using a log scale, 1/0, yes/no
;*************************************************************************
log_scale    = IntArr(numSDS)
log_scale[0] = 0 ; Surface Temperature
log_scale[1] = 0 ; Surface Pressure
log_scale[2] = 0 ; Cloud Top Pressure
log_scale[3] = 0 ; Cloud Top Temperature
log_scale[4] = 0 ; Effective Particle Radius
log_scale[5] = 1 ; Cloud Optical Thickness
log_scale[6] = 0 ; Effective Particle Rad, 2.1-1.6
log_scale[7] = 0 ; Effective Particle Rad, 3.7-2.1
log_scale[8] = 0 ; Water Path




;*************************************************************************
; End of definition section, make changes to the rest of the code at
; your own discretion.  If you wish to define a lat/lon box to plot,
; define it in the section below and choose the program call which
; includes the limits in the call.
;*************************************************************************




;*************************************************************************
; Loop over the SDSs, plotting only the desired ones.
;*************************************************************************
for icnt = 0, numSDS-1 do begin

   ;*************************************************************************
   ; Define the name of the output image file, including path:
   ;*************************************************************************
   OutFileName = output_dir+OutName[icnt]+'.'+Year+'.'+Day+'.'+Time+'.tiff'

   ;*************************************************************************
   ; Add a title to the plot if desired. Ex. titlestring ='Title'
   ;*************************************************************************
   titlestring = TitleName[icnt]+' ('+SDSunits[icnt]+')'+ $
                 '  Day '+Day+', '+Year+' '+Time+' UTC'

   ;*************************************************************************
   ;If you would like to specify the lat/lons to plot, please specify them
   ;   here.  This option is to be used if you want to specify a lat/lon box
   ;   of the granule(s) to plot.  The format is as follows:
   ;   limits=[NorthBound,WestBound,SouthBound,EastBound]
   ;If you want the program to compute the bounds, please set limits = 0
   ;*************************************************************************
   limits=0


   ;*************************************************************************
   ;Call the program:
   ;*************************************************************************
   ;Since these are two dim, set multidim_choice to 0:
   multidim_choice = MDChoice[icnt]
   ;Test to see if this SDS should be plotted:
   print, ''
   IF (PlotSDS[icnt] eq 1) then begin
      ;Call the plotting code:
      print, 'Plotting ',SDSName[icnt]
      SDS_limits = [SDSLimits[icnt,0],SDSLimits[icnt,1]]
      plot_l2, MOD06filename, SDSName[icnt],  $
               OutFileName, SDS_limits,       $
               titlestring, multidim_choice,      $
               Num_CB_Annotes[icnt], log_scale[icnt]
   ENDIF ELSE BEGIN
      print, 'Skipping ',SDSName[icnt]
   ENDELSE

;*************************************************************************
;End the looping:
;*************************************************************************
endfor


END
