PRO phase

;*************************************************************************
; Name: phase
;
; Purpose:
;   This rountine is the main driver to create plots which visualize ice and
;   water/undetermined/water+undetermined phases on the same plot, but with
;   separate color schemes.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   Input_Path     :  Directory where the L2 file is stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_phase.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************



;*************************************************************************
;  Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names.
;*************************************************************************
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')

;*************************************************************************
; Define the output directory:
;*************************************************************************
output_dir = GETENV('Output_Path')


;*************************************************************************
; Define the files that contain the Ancillary data, including path.  
;*************************************************************************
;Define the overall path where the files reside:
MOD06Path = GETENV('Input_Path')

;Define the MOD06 File Name:
file_spec = MOD06Path+'MOD06_*'+ Year + Day + '.' + Time + '*' 
result = FINDFILE(file_spec)
MOD06filename = strcompress(result(0))


;*************************************************************************
; Define the SDSs to plot.  If the SDS is to be plotted, set 
; the value to 1, if not, set to 0.
;*************************************************************************
numSDS     = 6
PlotSDS    = IntArr(numSDS)
PlotSDS[0] = 1 ; Effective Particle Radius 1.6
PlotSDS[1] = 1 ; Effective Particle Radius 2.1
PlotSDS[2] = 1 ; Effective Particle Radius 3.6
PlotSDS[3] = 1 ; EPRD, 1.6-2.1
PlotSDS[4] = 1 ; EPRD, 3.7-2.1
PlotSDS[5] = 1 ; Cloud Optical Thickness

;*************************************************************************
; Definition of the names to use in the output file names for each SDS:
;*************************************************************************
OutName    = StrArr(numSDS)
OutName[0] = 'Re_Phs_1.6'
OutName[1] = 'Re_Phs_2.1'
OutName[2] = 'Re_Phs_3.7'
OutName[3] = 'ReD_Phs_16'
OutName[4] = 'ReD_Phs_37'
OutName[5] = 'COT_Phs'

;*************************************************************************
; Definition of the names to use in the output file names for each SDS:
;*************************************************************************
TitleName    = StrArr(numSDS)
TitleName[0] = '1.6 Micron Effective Radius Retrieval'
TitleName[1] = '2.1 Micron Effective Radius Retrieval'
TitleName[2] = '3.7 Micron Effective Radius Retrieval'
TitleName[3] = '1.6-2.1 Effective Radius Difference Retrieval'
TitleName[4] = '3.7-2.1 Effective Radius Difference Retrieval'
TitleName[5] = 'Cloud Optical Thickness'

;*************************************************************************
; Define the SDS limits.  The array is the number of sds x ice/wate x min/max:
;*************************************************************************
SDSLimits      = FltArr(numSDS,2,2)
;1.6 Retrieval:
SDSLimits[0,0,0] =   6.0 ;Re 1.6, min, ice
SDSLimits[0,0,1] =  50.0 ;Re 1.6, max, ice
SDSLimits[0,1,0] =   2.0 ;Re 1.6, min, water
SDSLimits[0,1,1] =  30.0 ;Re 1.6, max, water
;2.1 Retrieval:
SDSLimits[1,0,0] =   6.0 ;Re 2.1, min, ice
SDSLimits[1,0,1] =  50.0 ;Re 2.1, max, ice
SDSLimits[1,1,0] =   2.0 ;Re 2.1, min, water
SDSLimits[1,1,1] =  30.0 ;Re 2.1, max, water
;3.7 Retrieval:
SDSLimits[2,0,0] =   6.0 ;Re 3.7, min, ice
SDSLimits[2,0,1] =  50.0 ;Re 3.7, max, ice
SDSLimits[2,1,0] =   2.0 ;Re 3.7, min, water
SDSLimits[2,1,1] =  30.0 ;Re 3.7, max, water
;1.6-21 Retrieval:
SDSLimits[3,0,0] =  -5.0 ;Re 1.6-2.1, min, ice
SDSLimits[3,0,1] =   5.0 ;Re 1.6-2.1, max, ice
SDSLimits[3,1,0] =  -5.0 ;Re 1.6-2.1, min, water
SDSLimits[3,1,1] =   5.0 ;Re 1.6-2.1, max, water
;3.7-2.1 Retrieval:
SDSLimits[4,0,0] =  -5.0 ;Re 3.7-2.1, min, ice
SDSLimits[4,0,1] =   5.0 ;Re 3.7-2.1, max, ice
SDSLimits[4,1,0] =  -5.0 ;Re 3.7-2.1, min, water
SDSLimits[4,1,1] =   5.0 ;Re 3.7-2.1, max, water
;Cloud Optical Thickness:
SDSLimits[5,0,0] =   1.0 ;COT, min, ice
SDSLimits[5,0,1] =  75.0 ;COT, max, ice
SDSLimits[5,1,0] =   1.0 ;COT, min, water
SDSLimits[5,1,1] =  75.0 ;COT, max, water


;*************************************************************************
; Define the limit around zero to gray out of the difference plots.
;*************************************************************************
delta_zero      = FltArr(numSDS,2)
delta_zero[0,0] = -1.0 ; Re 1.6, min
delta_zero[0,1] =  1.0 ; Re 1.6, max
delta_zero[1,0] = -1.0 ; Re 2.1, min
delta_zero[1,1] =  1.0 ; Re 2.1, max
delta_zero[2,0] = -1.0 ; Re 3.7, min
delta_zero[2,1] =  1.0 ; Re 3.7, max
delta_zero[3,0] = -1.0 ; Re Diff 1.6-2.1, min
delta_zero[3,1] =  1.0 ; Re Diff 1.6-2.1, max
delta_zero[4,0] = -1.0 ; Re Diff 3.7-2.1, min
delta_zero[4,1] =  1.0 ; Re Diff 3.7-2.1, max
delta_zero[5,0] = -1.0 ; COT, min
delta_zero[5,1] =  1.0 ; COT, max


;*************************************************************************
; Choose the number of text annotations to be included on the color bar:
;*************************************************************************
Num_CB_Annotes    = IntArr(numSDS)
Num_CB_Annotes[0] = 4 ;Re 1.6
Num_CB_Annotes[1] = 4 ;Re 2.1
Num_CB_Annotes[2] = 4 ;Re 3.7
Num_CB_Annotes[3] = 4 ;EPRD 1.6-2.1
Num_CB_Annotes[4] = 4 ;EPRD 3.7-2.1
Num_CB_Annotes[5] = 5 ;COT


;*************************************************************************
; Define the SDS units:
;*************************************************************************
SDSunits    = StrArr(numSDS)
SDSunits[0] = 'microns'
SDSunits[1] = 'microns'
SDSunits[2] = 'microns'
SDSunits[3] = 'microns'
SDSunits[4] = 'microns'
SDSunits[5] = 'none'

;*************************************************************************
; Definition of the names of the Ancillary SDS as defined in the HDF file.
;*************************************************************************
SDSName    = StrArr(numSDS)
SDSName[0] = 'Effective_Radius_Difference'
SDSName[1] = 'Effective_Particle_Radius'
SDSName[2] = 'Effective_Radius_Difference'
SDSName[3] = 'Effective_Radius_Difference'
SDSName[4] = 'Effective_Radius_Difference'
SDSName[5] = 'Cloud_Optical_Thickness'

;*************************************************************************
;Multi dimension choice:
; Single banded have MDchoice = 0, Multi banded start with 0.
;*************************************************************************
MDchoice    = IntArr(numSDS)
MDchoice[0] = 0 ; 1.6
MDchoice[1] = 0 ; 2.1
MDchoice[2] = 1 ; 3.7
MDchoice[3] = 0 ; 1.6-2.1
MDchoice[4] = 1 ; 3.7-2.1
MDchoice[5] = 0 ; COT

;*************************************************************************
;Flag to have difference plotted, yes/no, 1/0.
;*************************************************************************
diff_flag    = IntArr(numSDS)
diff_flag[0] = 0 ; 1.6
diff_flag[1] = 0 ; 2.1
diff_flag[2] = 0 ; 3.7
diff_flag[3] = 1 ; 1.6-2.1
diff_flag[4] = 1 ; 3.7-2.1
diff_flag[5] = 0 ; COT

;*************************************************************************
;Flag to plot just the water, undetermined, or water + undetermined.
; 0 = water, 1 = undetermined, 2 = water + undetermined 
;*************************************************************************
water_flag    = IntArr(numSDS)
water_flag[0] = 2 ; 1.6
water_flag[1] = 2 ; 2.1
water_flag[2] = 2 ; 3.7
water_flag[3] = 2 ; 1.6-2.1
water_flag[4] = 2 ; 3.7-2.1
water_flag[5] = 2 ; COT

;*************************************************************************
; Plot using a log scale, 1/0, yes/no
;*************************************************************************
log_scale    = IntArr(numSDS)
log_scale[0] = 0 ; 1.6
log_scale[1] = 0 ; 2.1 
log_scale[2] = 0 ; 3.7
log_scale[3] = 0 ; 1.6-2.1
log_scale[4] = 0 ; 3.7-2.1
log_scale[5] = 1 ; Cloud Optical Thickness




;*************************************************************************
; End of definition section, make changes to the rest of the code at
; your own discretion.  If you wish to define a lat/lon box to plot,
; define it in the section below and choose the program call which
; includes the limits in the call.
;*************************************************************************




;*************************************************************************
; Loop over the SDSs, plotting only the desired ones.
;*************************************************************************
for icnt = 0, numSDS-1 do begin

   ;*************************************************************************
   ; Define the name of the output image file, including path:
   ;*************************************************************************
   OutFileName = output_dir+OutName[icnt]+'.'+Year+'.'+Day+'.'+Time+'.tiff'

   ;*************************************************************************
   ; Add a title to the plot if desired. Ex. titlestring ='Title'
   ;*************************************************************************
   titlestring = TitleName[icnt]+' ('+SDSunits[icnt]+')'+ $
                 '  Day '+Day+', '+Year+' '+Time+' UTC.'

   ;*************************************************************************
   ;If you would like to specify the lat/lons to plot, please specify them
   ;   here.  This option is to be used if you want to specify a lat/lon box
   ;   of the granule(s) to plot.  The format is as follows:
   ;   limits=[NorthBound,WestBound,SouthBound,EastBound]
   ;If you want the program to compute the bounds, please set limits = 0.
   ;*************************************************************************
   limits=0

   ;*************************************************************************
   ;Call the program:
   ;*************************************************************************
   ;Since these are two dim, set multidim_choice to 0:
   multidim_choice = MDChoice[icnt]
   ;Test to see if this SDS should be plotted:
   IF (PlotSDS[icnt] eq 1) then begin
      ;Call the plotting code:
      print, 'Plotting ',TitleName[icnt]
      SDS_limits = fltarr(2,2)
      SDS_limits(*,*) = SDSLimits[icnt,*,*]
      delta_z    = [delta_zero[icnt,0],delta_zero[icnt,1]]
      plot_phase, MOD06filename, SDSName[icnt],        $
                  OutFileName, SDS_limits,             $
                  titlestring, multidim_choice,        $
                  Num_CB_Annotes[icnt],                 $
                  diff_flag[icnt], water_flag[icnt],   $
                  delta_z, log_scale[icnt]
   ENDIF ELSE BEGIN
      print, 'Skipping ',TitleName[icnt]
   ENDELSE

;*************************************************************************
;End the looping:
;*************************************************************************
endfor


END
