PRO re_phase

;*************************************************************************
; Name: re_phase
;
; Purpose:
;   This rountine is the main driver to create a three paneled plot 
;   which contains seperate phases, ice water and uncertain, for Re.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   Input_Path     :  Directory where the L2 file is stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_re_phase.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************

;*************************************************************************
;  Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names.
;*************************************************************************
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')


;*************************************************************************
; Define the output directory:
;*************************************************************************
output_dir = GETENV('Output_Path')



;*************************************************************************
; Define the files that contain the Ancillary data, including path.  
;*************************************************************************
;Specify the path where the MOD03, geolocation file resides:
;  Note:  Specify the full path:
fullpath = GETENV('Input_Path')

;Define the file name to look for and find the file:
file_spec = fullpath+'MOD06_*'+year+day+'.'+time+'*.hdf'
result = FINDFILE(file_spec)
MOD06filename = strcompress(result(0))
print, MOD06filename


;*************************************************************************
; Define the title to use above each plot:
;*************************************************************************
numSDS         = 3
Phase_Title    = StrArr(numSDS)
Phase_Title[0] = 'Ice'
Phase_Title[1] = 'Water'
Phase_Title[2] = 'Uncertain'


;*************************************************************************
; Define the SDS limits, as [min, max]:
;*************************************************************************
SDSLimits      = FltArr(numSDS,2)
SDSLimits[0,0] = 6.    ;Re - Ice, min
SDSLimits[0,1] = 50.   ;Re - Ice, max
SDSLimits[1,0] = 2.    ;Re - Water, min
SDSLimits[1,1] = 30.   ;Re - Water, max
SDSLimits[2,0] = 2.    ;Re - Uncertain, min
SDSLimits[2,1] = 30.   ;Re - Uncertain, max


;*************************************************************************
; Choose the number of text annotations to be included on the color bar:
;*************************************************************************
Num_CB_Annotes    = IntArr(numSDS)
Num_CB_Annotes[0] = 4 ;Re-Ice
Num_CB_Annotes[1] = 4 ;Re-Water
Num_CB_Annotes[2] = 4 ;Re-Uncerain






;*************************************************************************
; End of definition section, make changes to the rest of the code at
; your own discretion.  If you wish to define a lat/lon box to plot,
; define it in the section below and choose the program call which
; includes the limits in the call.
;*************************************************************************




;*************************************************************************
; Define the name of the output image file, including path:
;*************************************************************************
OutFileName = output_dir+'Three_Phs_Re.'+Year+'.'+Day+'.'+Time+'.tiff'

;*************************************************************************
; Add a title to the plot if desired. Ex. titlestring ='Title'
;*************************************************************************
titlestring = 'Effective Particle Radius'+' (microns)'+ $
                 '  Day '+Day+', '+Year+' '+Time+' UTC'

;*************************************************************************
; Call the program:
;*************************************************************************
;Since these are two dim, set multidim_choice to 0:
;Call the plotting code:
plot_re_phase, MOD06filename, OutFileName, SDSLimits,  $
               Phase_Title,titlestring, Num_CB_Annotes



END
